<?xml version="1.0" encoding="UTF-8"?>
<!-- FZ811v1.0_VALXSLTu3, 16-12-2019 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:fz="http://ei.vektis.nl/verantwoording/basisschema/v1_0"
xmlns:fz811="http://ei.vektis.nl/verantwoording/fz811/v1_0"
xmlns:fz812="http://ei.vektis.nl/verantwoording/fz812/v1_0" >
 	
 	
 	<xsl:import href="rc8028.xslt"/>
 	<xsl:import href="rc8986.xslt"/>
 	<xsl:import href="rc8991.xslt"/>
	<xsl:import href="rc9154a.xslt"/>
	<xsl:import href="rc9154b.xslt"/>
	<xsl:import href="rc9155.xslt"/>
	<xsl:import href="rc9156.xslt"/>
	<xsl:import href="rc9157.xslt"/>
	<xsl:import href="rc9158.xslt"/>

 	
	<!-- Uitvoer is fz812 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="Berichtcode" select="//fz811:Bericht/fz811:Header/fz811:Berichtcode"/> 
	<xsl:variable name="BerichtSoort" select="//fz811:Bericht/fz811:Header/fz811:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//fz811:Bericht/fz811:Header/fz811:Verzenddatum, '-', '')"/>

	<xsl:template match="//fz811:Bericht">
		<fz812:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/verantwoording/fz812/v1_0 fz812.xsd</xsl:attribute>
			<!-- Controleer op errors in de Header -->
			<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
			<xsl:variable name="rc8028">
				<xsl:call-template name="rc8028">
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable>
				
			<!-- retourcode 8920: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
			<xsl:variable name="rc8986">
				<xsl:call-template name="rc8986">
					<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable> 
			
			<xsl:choose>
				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">
					<xsl:apply-templates select="fz811:Header"/>
					<xsl:apply-templates select="fz811:Totaal"/>
					<xsl:apply-templates select="fz811:Plaatsingsbesluiten"/>
				</xsl:when>
				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="fz811:Header"/>
				</xsl:otherwise>
			</xsl:choose>
				
		</fz812:Bericht>
	</xsl:template>	

	<xsl:template match="fz811:Header">
		<fz812:Header>
			<fz812:Berichtcode>475</fz812:Berichtcode>
			<xsl:apply-templates select="fz811:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:BerichtSubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:CodeServicebureau" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Instellingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:UzoviNummer" mode="copy-if-exists"/>			
			<xsl:apply-templates select="fz811:AfzenderReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:EinddatumVerantwoordingsperiode" mode="copy-if-exists"/>
			
  	       	<fz812:Retourcodes>
				
				<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
				<xsl:variable name="rc8028">
					<xsl:call-template name="rc8028">
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable>
					
				<!-- retourcode 8920: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
				<xsl:variable name="rc8986">
					<xsl:call-template name="rc8986">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable> 

					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>

					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<fz812:Retourcode>0200</fz812:Retourcode>
				</xsl:if>
					
			</fz812:Retourcodes>
		</fz812:Header>
	</xsl:template>
		
	<xsl:template match="fz811:Totaal">	
		<fz812:Totaal>
			<xsl:apply-templates select="fz811:TotaalOHWDBBC"/>
			<xsl:apply-templates select="fz811:TotaalANGDBBC"/>
				
			<fz812:Retourcodes>
				<fz812:Retourcode>0200</fz812:Retourcode>
			</fz812:Retourcodes>	
			
		</fz812:Totaal>
	</xsl:template>
		
	<xsl:template match="fz811:TotaalOHWDBBC">	
		<fz812:TotaalOHWDBBC>
			<xsl:apply-templates select="fz811:SomTotaalbedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:SomVerblijfsdagenKalenderjaarSGLVG" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsperiodenKalenderjaar"/>
		</fz812:TotaalOHWDBBC>
	</xsl:template>
		
	<xsl:template match="fz811:TotaalANGDBBC">	
		<fz812:TotaalANGDBBC>
			<xsl:apply-templates select="fz811:SomTotaalbedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:SomVerblijfsdagenKalenderjaarSGLVG" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsperiodenKalenderjaar"/>
		</fz812:TotaalANGDBBC>
	</xsl:template>
		
	<xsl:template match="fz811:Plaatsingsbesluiten">
		<fz812:Plaatsingsbesluiten>
			<xsl:apply-templates select="fz811:Plaatsingsbesluit"/>
		</fz812:Plaatsingsbesluiten>
	</xsl:template>

	<xsl:template match="fz811:Plaatsingsbesluit">
		<fz812:Plaatsingsbesluit>
			<xsl:apply-templates select="fz811:Zorgcontractnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Plaatsingsbesluitnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Verzekerdennummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:BegindatumPrestatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:OHWDBBC"/>
			<xsl:apply-templates select="fz811:ANGDBBC"/>
				
			<fz812:Retourcodes>
			
				<xsl:variable name="EinddatumVerantwoordingsperiode" select="translate(//fz811:Bericht/fz811:Header/fz811:EinddatumVerantwoordingsperiode, '-', '')"/>
				
				<xsl:if test="fz811:OHWDBBC">	
					<!-- retourcode 8991: Het totaalbedrag in Plaatsingsbesluit moet gelijk zijn aan de som van alle bedragen.  -->
					<xsl:variable name="rc8991">
						<xsl:call-template name="rc8991">					
							<xsl:with-param name="BehandelingsKosten" select="translate(number(fz811:OHWDBBC/fz811:BehandelingsKosten), 'aN', '0')"/>							
							<xsl:with-param name="FPTKosten" select="translate(number(fz811:OHWDBBC/fz811:FPTKosten), 'aN', '0')"/>							
							<xsl:with-param name="DagbestedingsKosten" select="translate(number(fz811:OHWDBBC/fz811:DagbestedingsKosten), 'aN', '0')"/>							
							<xsl:with-param name="MethadonKosten" select="translate(number(fz811:OHWDBBC/fz811:MethadonKosten), 'aN', '0')"/>							
							<xsl:with-param name="ECTKosten" select="translate(number(fz811:OHWDBBC/fz811:ECTKosten), 'aN', '0')"/>							
							<xsl:with-param name="ToeslagTolkGebarentaal-Communicatiespecialist" select="translate(number(fz811:OHWDBBC/fz811:ToeslagTolkGebarentaal-Communicatiespecialist), 'aN', '0')"/>							
							<xsl:with-param name="VerblijfsKosten" select="translate(number(fz811:OHWDBBC/fz811:VerblijfsKosten), 'aN', '0')"/>							
							<xsl:with-param name="OverigeProductenEVBGKosten" select="translate(number(fz811:OHWDBBC/fz811:OverigeProductenEVBGKosten), 'aN', '0')"/>							
							<xsl:with-param name="Totaalbedrag" select="fz811:OHWDBBC/fz811:Totaalbedrag"/>		
						</xsl:call-template>
					</xsl:variable>
						
					<!-- retourcode 9154a: TotaalAantalVerblijfsdagenKalenderjaar ontbreekt of is onjuist.-->
					<xsl:variable name="rc9154a">
						<xsl:call-template name="rc9154a">
							<xsl:with-param name="TotaalAantalVerblijfsdagenKalenderjaar" select="fz811:OHWDBBC/fz811:TotaalAantalVerblijfsdagenKalenderjaar"/>
							<xsl:with-param name="Totaaldagen" select="sum(fz811:OHWDBBC/fz811:VerblijfsperiodenKalenderjaar/fz811:VerblijfsperiodeKalenderjaar/fz811:VerblijfsdagenKalenderjaar)"/>			
						</xsl:call-template>
					</xsl:variable>
					
					<!-- retourcode 9154b: TotaalAantalVerblijfsdagenKalenderjaar moet kleiner of gelijk zijn aan het aantal kalenderdagen in verantwoordingsperiode.-->
					<xsl:variable name="rc9154b">
						<xsl:call-template name="rc9154b">
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz811:BegindatumPrestatie, '-', '')"/>
							<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
							<xsl:with-param name="TotaalAantalVerblijfsdagenKalenderjaar" select="fz811:OHWDBBC/fz811:TotaalAantalVerblijfsdagenKalenderjaar"/>
						</xsl:call-template>
					</xsl:variable>
					
					<!-- retourcode 9155: BegindatumPrestatie moet kleiner zijn dan of gelijk zijn aan de verzenddatum. -->
					<xsl:variable name="rc9155">
						<xsl:call-template name="rc9155">
							<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz811:BegindatumPrestatie, '-', '')"/>
						</xsl:call-template>
					</xsl:variable>
						
					<!-- retourcode 9156: BegindatumPrestatie mag voor OHW niet meer dan een jaar voor de EinddatumVerantwoordingsperiode liggen -->
					<xsl:variable name="rc9156">
						<xsl:call-template name="rc9156">
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz811:BegindatumPrestatie, '-', '')"/>
							<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
						</xsl:call-template>
					</xsl:variable>
					
					<!-- retourcode 9157: Verblijfskosten ontbreekt of is onjuist.-->
					<xsl:variable name="rc9157">
						<xsl:call-template name="rc9157">
							<xsl:with-param name="TotaalAantalVerblijfsdagenKalenderjaar" select="fz811:OHWDBBC/fz811:TotaalAantalVerblijfsdagenKalenderjaar"/>
							<xsl:with-param name="VerblijfsKosten" select="translate(number(fz811:OHWDBBC/fz811:VerblijfsKosten), 'aN', '0')"/>							
						</xsl:call-template>
					</xsl:variable>
						
					<!-- retourcode 9158: VerblijfsdagenKalenderjaarSGLVG ontbreekt of is onjuist.-->
					<xsl:variable name="rc9158">
						<xsl:call-template name="rc9158">
							<xsl:with-param name="VerblijfsdagenKalenderjaarSGLVG" select="fz811:OHWDBBC/fz811:VerblijfsdagenKalenderjaarSGLVG"/>
							<xsl:with-param name="TotaaldagenSGLVG2" select="sum(fz811:OHWDBBC/fz811:VerblijfsperiodenKalenderjaar/fz811:VerblijfsperiodeKalenderjaar[fz811:Beveiligingsniveau=2]/fz811:VerblijfsdagenKalenderjaar)"/>					
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:copy-of select="$rc8991"/>
					<xsl:copy-of select="$rc9154a"/>	
					<xsl:copy-of select="$rc9154b"/>
					<xsl:copy-of select="$rc9155"/>
					<xsl:copy-of select="$rc9156"/>
					<xsl:copy-of select="$rc9157"/>	
					<xsl:copy-of select="$rc9158"/>	
					
					<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
					<xsl:if test="$rc8991='' and $rc9154a='' and $rc9154b='' and $rc9155='' and $rc9156='' and $rc9157='' and $rc9158=''">
						<fz812:Retourcode>0200</fz812:Retourcode>
					</xsl:if>					
				</xsl:if>		
					
				<xsl:if test="fz811:ANGDBBC">					
						<!-- retourcode 8991: Het totaalbedrag in Plaatsingsbesluit moet gelijk zijn aan de som van alle bedragen.  -->
					<xsl:variable name="rc8991">
						<xsl:call-template name="rc8991">					
							<xsl:with-param name="BehandelingsKosten" select="translate(number(fz811:ANGDBBC/fz811:BehandelingsKosten), 'aN', '0')"/>							
							<xsl:with-param name="FPTKosten" select="translate(number(fz811:ANGDBBC/fz811:FPTKosten), 'aN', '0')"/>							
							<xsl:with-param name="DagbestedingsKosten" select="translate(number(fz811:ANGDBBC/fz811:DagbestedingsKosten), 'aN', '0')"/>							
							<xsl:with-param name="MethadonKosten" select="translate(number(fz811:ANGDBBC/fz811:MethadonKosten), 'aN', '0')"/>							
							<xsl:with-param name="ECTKosten" select="translate(number(fz811:ANGDBBC/fz811:ECTKosten), 'aN', '0')"/>							
							<xsl:with-param name="ToeslagTolkGebarentaal-Communicatiespecialist" select="translate(number(fz811:ANGDBBC/fz811:ToeslagTolkGebarentaal-Communicatiespecialist), 'aN', '0')"/>							
							<xsl:with-param name="VerblijfsKosten" select="translate(number(fz811:ANGDBBC/fz811:VerblijfsKosten), 'aN', '0')"/>							
							<xsl:with-param name="OverigeProductenEVBGKosten" select="translate(number(fz811:ANGDBBC/fz811:OverigeProductenEVBGKosten), 'aN', '0')"/>							
							<xsl:with-param name="Totaalbedrag" select="fz811:ANGDBBC/fz811:Totaalbedrag"/>		
						</xsl:call-template>
					</xsl:variable>				
						
					<!-- retourcode 9154a: TotaalAantalVerblijfsdagenKalenderjaar ontbreekt of is onjuist.-->
					<xsl:variable name="rc9154a">
						<xsl:call-template name="rc9154a">
							<xsl:with-param name="TotaalAantalVerblijfsdagenKalenderjaar" select="fz811:ANGDBBC/fz811:TotaalAantalVerblijfsdagenKalenderjaar"/>
							<xsl:with-param name="Totaaldagen" select="sum(fz811:ANGDBBC/fz811:VerblijfsperiodenKalenderjaar/fz811:VerblijfsperiodeKalenderjaar/fz811:VerblijfsdagenKalenderjaar)"/>			
						</xsl:call-template>
					</xsl:variable>
						
					<!-- retourcode 9154b: TotaalAantalVerblijfsdagenKalenderjaar moet kleiner of gelijk zijn aan het aantal kalenderdagen in verantwoordingsperiode.-->
					<xsl:variable name="rc9154b">
						<xsl:call-template name="rc9154b">
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz811:BegindatumPrestatie, '-', '')"/>
							<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
							<xsl:with-param name="TotaalAantalVerblijfsdagenKalenderjaar" select="fz811:ANGDBBC/fz811:TotaalAantalVerblijfsdagenKalenderjaar"/>
						</xsl:call-template>
					</xsl:variable>
						
					<!-- retourcode 9155: BegindatumPrestatie moet kleiner zijn dan of gelijk zijn aan de verzenddatum. -->
					<xsl:variable name="rc9155">
						<xsl:call-template name="rc9155">
							<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
							<xsl:with-param name="BegindatumPrestatie" select="translate(fz811:BegindatumPrestatie, '-', '')"/>
						</xsl:call-template>
					</xsl:variable>
					
					<!-- retourcode 9157: Verblijfskosten ontbreekt of is onjuist.-->
					<xsl:variable name="rc9157">
						<xsl:call-template name="rc9157">
							<xsl:with-param name="TotaalAantalVerblijfsdagenKalenderjaar" select="fz811:ANGDBBC/fz811:TotaalAantalVerblijfsdagenKalenderjaar"/>
							<xsl:with-param name="VerblijfsKosten" select="translate(number(fz811:ANGDBBC/fz811:VerblijfsKosten), 'aN', '0')"/>							
						</xsl:call-template>
					</xsl:variable>
					
					<!-- retourcode 9158: VerblijfsdagenKalenderjaarSGLVG ontbreekt of is onjuist.-->
					<xsl:variable name="rc9158">
						<xsl:call-template name="rc9158">
							<xsl:with-param name="VerblijfsdagenKalenderjaarSGLVG" select="fz811:ANGDBBC/fz811:VerblijfsdagenKalenderjaarSGLVG"/>
							<xsl:with-param name="TotaaldagenSGLVG2" select="sum(fz811:ANGDBBC/fz811:VerblijfsperiodenKalenderjaar/fz811:VerblijfsperiodeKalenderjaar[fz811:Beveiligingsniveau=2]/fz811:VerblijfsdagenKalenderjaar)"/>					
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:copy-of select="$rc8991"/>
					<xsl:copy-of select="$rc9154a"/>
					<xsl:copy-of select="$rc9154b"/>	
					<xsl:copy-of select="$rc9155"/>
					<xsl:copy-of select="$rc9157"/>	
					<xsl:copy-of select="$rc9158"/>	
					
					<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
					<xsl:if test="$rc8991='' and $rc9154a='' and $rc9154b='' and $rc9155='' and $rc9157='' and $rc9158=''">
						<fz812:Retourcode>0200</fz812:Retourcode>
					</xsl:if>					
				</xsl:if>	
				
			</fz812:Retourcodes>			
			
		</fz812:Plaatsingsbesluit>
	</xsl:template>
	
	<xsl:template match="fz811:OHWDBBC">
		<fz812:OHWDBBC>
			<xsl:apply-templates select="fz811:BehandelingsKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:FPTKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:DagbestedingsKosten" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz811:MethadonKosten" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz811:ECTKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:ToeslagTolkGebarentaal-Communicatiespecialist" mode="copy-if-exists"/>			
			<xsl:apply-templates select="fz811:VerblijfsKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:OverigeProductenEVBGKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Totaalbedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:TotaalAantalVerblijfsdagenKalenderjaar" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsdagenKalenderjaarSGLVG" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsperiodenKalenderjaar"/>
		</fz812:OHWDBBC>
	</xsl:template>

	<xsl:template match="fz811:ANGDBBC">
		<fz812:ANGDBBC>
			<xsl:apply-templates select="fz811:BehandelingsKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:FPTKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:DagbestedingsKosten" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz811:MethadonKosten" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz811:ECTKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:ToeslagTolkGebarentaal-Communicatiespecialist" mode="copy-if-exists"/>			
			<xsl:apply-templates select="fz811:VerblijfsKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:OverigeProductenEVBGKosten" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Totaalbedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:TotaalAantalVerblijfsdagenKalenderjaar" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsdagenKalenderjaarSGLVG" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsperiodenKalenderjaar"/>
		</fz812:ANGDBBC>
	</xsl:template>
		
	<xsl:template match="fz811:VerblijfsperiodenKalenderjaar">
		<fz812:VerblijfsperiodenKalenderjaar>
			<xsl:apply-templates select="fz811:VerblijfsperiodeKalenderjaar"/>
		</fz812:VerblijfsperiodenKalenderjaar>
	</xsl:template>
		
	<xsl:template match="fz811:VerblijfsperiodeKalenderjaar">
		<fz812:VerblijfsperiodeKalenderjaar>
			<xsl:apply-templates select="fz811:Beveiligingsniveau" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:Verblijfsintensiteit" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz811:VerblijfsdagenKalenderjaar" mode="copy-if-exists"/>
		</fz812:VerblijfsperiodeKalenderjaar>
	</xsl:template>
		
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'fz812:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>